% AcquisitionsApi - Acquisition operations
%
% AcquisitionsApi Properties:
%    apiClient - ApiClient instance
%
% AcquisitionsApi Methods
%    addAcquisition                             - Create a new acquisition
%    addAcquisitionAnalysis                     - Create an analysis and upload files.
%    addAcquisitionAnalysisNote                 - Add a note to acquisition analysis.
%    addAcquisitionNote                         - Add a note to acquisition.
%    addAcquisitionTag                          - Add a tag to acquisition.
%    deleteAcquisition                          - Delete a acquisition
%    deleteAcquisitionAnalysis                  - Delete an anaylsis
%    deleteAcquisitionAnalysisNote              - Remove a note from acquisition analysis.
%    deleteAcquisitionFile                      - Delete a file
%    deleteAcquisitionNote                      - Remove a note from acquisition
%    deleteAcquisitionTag                       - Delete a tag
%    downloadAcquisitionAnalysisInputs          - Download analysis inputs.
%    downloadAcquisitionAnalysisOutputs         - Download analysis outputs.
%    downloadFileFromAcquisition                - Download a file.
%    getAcquisitionFileZipInfo                  - Download a file.
%    getAcquisitionDownloadTicket               - Download a file.
%    downloadInputFromAcquisitionAnalysis       - Download analysis inputs with filter.
%    getAcquisitionAnalysisInputZipInfo         - Download analysis inputs with filter.
%    getAcquisitionAnalysisInputDownloadTicket  - Download analysis inputs with filter.
%    downloadOutputFromAcquisitionAnalysis      - Download analysis outputs with filter.
%    getAcquisitionAnalysisOutputZipInfo        - Download analysis outputs with filter.
%    getAcquisitionAnalysisOutputDownloadTicket - Download analysis outputs with filter.
%    getAcquisition                             - Get a single acquisition
%    getAcquisitionAnalyses                     - Get analyses for acquisition.
%    getAcquisitionAnalysis                     - Get an analysis.
%    getAcquisitionFileInfo                     - Get info for a particular file.
%    getAcquisitionNote                         - Get a note on acquisition.
%    getAcquisitionTag                          - Get the value of a tag, by name.
%    getAllAcquisitions                         - Get a list of acquisitions
%    modifyAcquisition                          - Update a acquisition
%    modifyAcquisitionAnalysis                  - Modify an analysis.
%    modifyAcquisitionFile                      - Modify a file's attributes
%    modifyAcquisitionFileClassification        - Update classification for a particular file.
%    modifyAcquisitionFileInfo                  - Update info for a particular file.
%    modifyAcquisitionInfo                      - Update or replace info for a acquisition.
%    modifyAcquisitionNote                      - Update a note on acquisition.
%    renameAcquisitionTag                       - Rename a tag.
%    replaceAcquisitionFile                     - Replace a file
%    uploadFileToAcquisition                    - Upload a file to acquisition.
%    uploadOutputToAcquisitionAnalysis          - Upload an output file to analysis.
classdef AcquisitionsApi < handle
    % NOTE: This file is auto generated by the swagger code generator program.
    % Do not edit the file manually.
    properties
        apiClient
        context_
    end
    methods
        function obj = AcquisitionsApi(apiClient, context)
            obj.apiClient = apiClient;
            obj.context_ = context;
        end

        function [returnData, resp] = addAcquisition(obj, body, varargin)
            % Create a new acquisition
            % body (Acquisition)
            % returns: [ContainerNewOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, body, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Acquisition.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.ContainerNewOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = addAcquisitionAnalysis(obj, acquisitionId, body, varargin)
            % Create an analysis and upload files.
            % acquisitionId (char)
            % body (AnalysisInput)
            % job (logical):Return job as an object instead of an id
            % returns: [ContainerNewOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'job', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.job)
                queryParams = [queryParams, 'job', flywheel.ApiClient.castParam(x__inp.Results.job, 'logical')];
            else
                queryParams = [queryParams, 'job', 'true'];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.AnalysisInput.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/analyses', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.ContainerNewOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = addAcquisitionAnalysisNote(obj, acquisitionId, analysisId, body, varargin)
            % Add a note to acquisition analysis.
            % acquisitionId (char)
            % analysisId (char)
            % body (Note)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Note.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/notes', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = addAcquisitionNote(obj, acquisitionId, body, varargin)
            % Add a note to acquisition.
            % acquisitionId (char)
            % body (Note)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Note.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/notes', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = addAcquisitionTag(obj, acquisitionId, body, varargin)
            % Add a tag to acquisition.
            % acquisitionId (char)
            % body (Tag)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Tag.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/tags', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = deleteAcquisition(obj, acquisitionId, varargin)
            % Delete a acquisition
            % acquisitionId (char)
            % returns: [InlineResponse2002, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('DELETE', '/acquisitions/{AcquisitionId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse2002.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = deleteAcquisitionAnalysis(obj, acquisitionId, analysisId, varargin)
            % Delete an anaylsis
            % acquisitionId (char)
            % analysisId (char)
            % returns: [InlineResponse2002, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('DELETE', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse2002.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = deleteAcquisitionAnalysisNote(obj, acquisitionId, analysisId, noteId, varargin)
            % Remove a note from acquisition analysis.
            % acquisitionId (char)
            % analysisId (char)
            % noteId (char)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'noteId');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, noteId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.noteId)
                pathParams = [pathParams, 'NoteId', x__inp.Results.noteId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('DELETE', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/notes/{NoteId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = deleteAcquisitionFile(obj, acquisitionId, fileName, varargin)
            % Delete a file
            % acquisitionId (char)
            % fileName (char)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('DELETE', '/acquisitions/{AcquisitionId}/files/{FileName}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = deleteAcquisitionNote(obj, acquisitionId, noteId, varargin)
            % Remove a note from acquisition
            % acquisitionId (char)
            % noteId (char)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'noteId');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, noteId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.noteId)
                pathParams = [pathParams, 'NoteId', x__inp.Results.noteId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('DELETE', '/acquisitions/{AcquisitionId}/notes/{NoteId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = deleteAcquisitionTag(obj, acquisitionId, tagValue, varargin)
            % Delete a tag
            % acquisitionId (char)
            % tagValue (char):The tag to interact with
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'tagValue');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, tagValue, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.tagValue)
                pathParams = [pathParams, 'TagValue', x__inp.Results.tagValue];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('DELETE', '/acquisitions/{AcquisitionId}/tags/{TagValue}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = downloadAcquisitionAnalysisInputs(obj, acquisitionId, analysisId, varargin)
            % Download analysis inputs.
            % acquisitionId (char)
            % analysisId (char)
            % ticket (char):ticket id of the inputs to download
            % returns: [AnalysisFilesCreateTicketOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/inputs', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.AnalysisFilesCreateTicketOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = downloadAcquisitionAnalysisOutputs(obj, acquisitionId, analysisId, varargin)
            % Download analysis outputs.
            % acquisitionId (char)
            % analysisId (char)
            % ticket (char):ticket id of the outputs to download
            % returns: [AnalysisFilesCreateTicketOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/files', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.AnalysisFilesCreateTicketOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = downloadFileFromAcquisition(obj, acquisitionId, fileName, varargin)
            % Download a file.
            % acquisitionId (char)
            % fileName (char)
            % view (logical):If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % signature (char):Url's signature (signed download url)
            % expires (char):Signed url expiration time (epoch time)
            % destFile - Destination file path
            % returns: [DownloadTicket, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addParameter(x__inp, 'view', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'signature', []);
            addParameter(x__inp, 'expires', []);
            addRequired(x__inp, 'destFile');
            addParameter(x__inp, 'OutputType', 'double');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.view)
                queryParams = [queryParams, 'view', flywheel.ApiClient.castParam(x__inp.Results.view, 'logical')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end
            if ~isempty(x__inp.Results.signature)
                queryParams = [queryParams, 'signature', flywheel.ApiClient.castParam(x__inp.Results.signature, 'char')];
            end
            if ~isempty(x__inp.Results.expires)
                queryParams = [queryParams, 'expires', flywheel.ApiClient.castParam(x__inp.Results.expires, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/files/{FileName}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    destFile = x__inp.Results.destFile;
                    if ~isempty(destFile)
                        resp.saveResponseBodyToFile(destFile);
                        returnData = destFile;
                    else
                        returnData = resp.getBodyData(x__inp.Results.OutputType);
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionFileZipInfo(obj, acquisitionId, fileName, varargin)
            % Download a file.
            % acquisitionId (char)
            % fileName (char)
            % ticket (char):The generated ticket id for the download, or present but empty to generate a ticket id
            % view (logical):If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % signature (char):Url's signature (signed download url)
            % expires (char):Signed url expiration time (epoch time)
            % returns: [FileZipInfo, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'view', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'signature', []);
            addParameter(x__inp, 'expires', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end
            if ~isempty(x__inp.Results.view)
                queryParams = [queryParams, 'view', flywheel.ApiClient.castParam(x__inp.Results.view, 'logical')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            else
                queryParams = [queryParams, 'info', 'true'];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end
            if ~isempty(x__inp.Results.signature)
                queryParams = [queryParams, 'signature', flywheel.ApiClient.castParam(x__inp.Results.signature, 'char')];
            end
            if ~isempty(x__inp.Results.expires)
                queryParams = [queryParams, 'expires', flywheel.ApiClient.castParam(x__inp.Results.expires, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/files/{FileName}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.FileZipInfo.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionDownloadTicket(obj, acquisitionId, fileName, varargin)
            % Download a file.
            % acquisitionId (char)
            % fileName (char)
            % ticket (char):The generated ticket id for the download, or present but empty to generate a ticket id
            % view (logical):If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % signature (char):Url's signature (signed download url)
            % expires (char):Signed url expiration time (epoch time)
            % returns: [DownloadTicket, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'view', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'signature', []);
            addParameter(x__inp, 'expires', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end
            if ~isempty(x__inp.Results.view)
                queryParams = [queryParams, 'view', flywheel.ApiClient.castParam(x__inp.Results.view, 'logical')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end
            if ~isempty(x__inp.Results.signature)
                queryParams = [queryParams, 'signature', flywheel.ApiClient.castParam(x__inp.Results.signature, 'char')];
            end
            if ~isempty(x__inp.Results.expires)
                queryParams = [queryParams, 'expires', flywheel.ApiClient.castParam(x__inp.Results.expires, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/files/{FileName}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.DownloadTicket.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = downloadInputFromAcquisitionAnalysis(obj, acquisitionId, analysisId, filename, varargin)
            % Download analysis inputs with filter.
            % acquisitionId (char)
            % analysisId (char)
            % filename (char):filename to download (get tar of all if empty)
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % destFile - Destination file path
            % returns: [AnalysisFilesCreateTicketOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'filename');
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addRequired(x__inp, 'destFile');
            addParameter(x__inp, 'OutputType', 'double');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, filename, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.filename)
                pathParams = [pathParams, 'Filename', x__inp.Results.filename];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/inputs/{Filename}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    destFile = x__inp.Results.destFile;
                    if ~isempty(destFile)
                        resp.saveResponseBodyToFile(destFile);
                        returnData = destFile;
                    else
                        returnData = resp.getBodyData(x__inp.Results.OutputType);
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionAnalysisInputZipInfo(obj, acquisitionId, analysisId, filename, varargin)
            % Download analysis inputs with filter.
            % acquisitionId (char)
            % analysisId (char)
            % filename (char):filename to download (get tar of all if empty)
            % ticket (char):ticket id of the inputs to download
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % returns: [FileZipInfo, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'filename');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, filename, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.filename)
                pathParams = [pathParams, 'Filename', x__inp.Results.filename];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            else
                queryParams = [queryParams, 'info', 'true'];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/inputs/{Filename}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.FileZipInfo.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionAnalysisInputDownloadTicket(obj, acquisitionId, analysisId, filename, varargin)
            % Download analysis inputs with filter.
            % acquisitionId (char)
            % analysisId (char)
            % filename (char):filename to download (get tar of all if empty)
            % ticket (char):ticket id of the inputs to download
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % returns: [AnalysisFilesCreateTicketOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'filename');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, filename, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.filename)
                pathParams = [pathParams, 'Filename', x__inp.Results.filename];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/inputs/{Filename}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.AnalysisFilesCreateTicketOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = downloadOutputFromAcquisitionAnalysis(obj, acquisitionId, analysisId, filename, varargin)
            % Download analysis outputs with filter.
            % acquisitionId (char)
            % analysisId (char)
            % filename (char):filename to download (get tar of all if empty)
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % destFile - Destination file path
            % returns: [AnalysisFilesCreateTicketOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'filename');
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addRequired(x__inp, 'destFile');
            addParameter(x__inp, 'OutputType', 'double');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, filename, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.filename)
                pathParams = [pathParams, 'Filename', x__inp.Results.filename];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/files/{Filename}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    destFile = x__inp.Results.destFile;
                    if ~isempty(destFile)
                        resp.saveResponseBodyToFile(destFile);
                        returnData = destFile;
                    else
                        returnData = resp.getBodyData(x__inp.Results.OutputType);
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionAnalysisOutputZipInfo(obj, acquisitionId, analysisId, filename, varargin)
            % Download analysis outputs with filter.
            % acquisitionId (char)
            % analysisId (char)
            % filename (char):filename to download (get tar of all if empty)
            % ticket (char):ticket id of the outputs to download
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % returns: [FileZipInfo, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'filename');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, filename, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.filename)
                pathParams = [pathParams, 'Filename', x__inp.Results.filename];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            else
                queryParams = [queryParams, 'info', 'true'];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/files/{Filename}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.FileZipInfo.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionAnalysisOutputDownloadTicket(obj, acquisitionId, analysisId, filename, varargin)
            % Download analysis outputs with filter.
            % acquisitionId (char)
            % analysisId (char)
            % filename (char):filename to download (get tar of all if empty)
            % ticket (char):ticket id of the outputs to download
            % info (logical):If the file is a zipfile, return a json response of zipfile member information
            % member (char):The filename of a zipfile member to download rather than the entire file
            % returns: [AnalysisFilesCreateTicketOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'filename');
            addParameter(x__inp, 'ticket', []);
            addParameter(x__inp, 'info', []);
            addParameter(x__inp, 'member', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, filename, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end
            if ~isempty(x__inp.Results.filename)
                pathParams = [pathParams, 'Filename', x__inp.Results.filename];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.ticket)
                queryParams = [queryParams, 'ticket', flywheel.ApiClient.castParam(x__inp.Results.ticket, 'char')];
            end
            if ~isempty(x__inp.Results.info)
                queryParams = [queryParams, 'info', flywheel.ApiClient.castParam(x__inp.Results.info, 'logical')];
            end
            if ~isempty(x__inp.Results.member)
                queryParams = [queryParams, 'member', flywheel.ApiClient.castParam(x__inp.Results.member, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/files/{Filename}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.AnalysisFilesCreateTicketOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisition(obj, acquisitionId, varargin)
            % Get a single acquisition
            % acquisitionId (char)
            % returns: [Acquisition, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.Acquisition.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionAnalyses(obj, acquisitionId, varargin)
            % Get analyses for acquisition.
            % acquisitionId (char)
            % filter (char):The filter to apply. (e.g. label=my-label,created>2018-09-22)
            % sort (char):The sort fields and order. (e.g. label:asc,created:desc)
            % limit (integer):The maximum number of entries to return.
            % skip (integer):The number of entries to skip.
            % page (integer):The page number (i.e. skip limit*page entries)
            % afterId (char):Paginate after the given id. (Cannot be used with sort, page or skip)
            % returns: [vector[AnalysisListEntry], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addParameter(x__inp, 'filter', []);
            addParameter(x__inp, 'sort', []);
            addParameter(x__inp, 'limit', []);
            addParameter(x__inp, 'skip', []);
            addParameter(x__inp, 'page', []);
            addParameter(x__inp, 'afterId', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.filter)
                queryParams = [queryParams, 'filter', flywheel.ApiClient.castParam(x__inp.Results.filter, 'char')];
            end
            if ~isempty(x__inp.Results.sort)
                queryParams = [queryParams, 'sort', flywheel.ApiClient.castParam(x__inp.Results.sort, 'char')];
            end
            if ~isempty(x__inp.Results.limit)
                queryParams = [queryParams, 'limit', flywheel.ApiClient.castParam(x__inp.Results.limit, 'integer')];
            end
            if ~isempty(x__inp.Results.skip)
                queryParams = [queryParams, 'skip', flywheel.ApiClient.castParam(x__inp.Results.skip, 'integer')];
            end
            if ~isempty(x__inp.Results.page)
                queryParams = [queryParams, 'page', flywheel.ApiClient.castParam(x__inp.Results.page, 'integer')];
            end
            if ~isempty(x__inp.Results.afterId)
                queryParams = [queryParams, 'after_id', flywheel.ApiClient.castParam(x__inp.Results.afterId, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.AnalysisListEntry.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionAnalysis(obj, acquisitionId, analysisId, varargin)
            % Get an analysis.
            % acquisitionId (char)
            % analysisId (char)
            % inflateJob (logical):Return job as an object instead of an id
            % returns: [AnalysisOutput, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addParameter(x__inp, 'inflateJob', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.inflateJob)
                queryParams = [queryParams, 'inflate_job', flywheel.ApiClient.castParam(x__inp.Results.inflateJob, 'logical')];
            else
                queryParams = [queryParams, 'inflate_job', 'true'];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.AnalysisOutput.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionFileInfo(obj, acquisitionId, fileName, varargin)
            % Get info for a particular file.
            % acquisitionId (char)
            % fileName (char)
            % returns: [FileEntry, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/files/{FileName}/info', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.FileEntry.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionNote(obj, acquisitionId, noteId, varargin)
            % Get a note on acquisition.
            % acquisitionId (char)
            % noteId (char)
            % returns: [Note, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'noteId');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, noteId, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.noteId)
                pathParams = [pathParams, 'NoteId', x__inp.Results.noteId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/notes/{NoteId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.Note.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAcquisitionTag(obj, acquisitionId, tagValue, varargin)
            % Get the value of a tag, by name.
            % acquisitionId (char)
            % tagValue (char):The tag to interact with
            % returns: [Tag, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'tagValue');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, tagValue, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.tagValue)
                pathParams = [pathParams, 'TagValue', x__inp.Results.tagValue];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions/{AcquisitionId}/tags/{TagValue}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.Tag.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAllAcquisitions(obj, varargin)
            % Get a list of acquisitions
            % exhaustive (logical):Set to return a complete list regardless of permissions
            % filter (char):The filter to apply. (e.g. label=my-label,created>2018-09-22)
            % sort (char):The sort fields and order. (e.g. label:asc,created:desc)
            % limit (integer):The maximum number of entries to return.
            % skip (integer):The number of entries to skip.
            % page (integer):The page number (i.e. skip limit*page entries)
            % afterId (char):Paginate after the given id. (Cannot be used with sort, page or skip)
            % returns: [vector[Acquisition], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'exhaustive', []);
            addParameter(x__inp, 'filter', []);
            addParameter(x__inp, 'sort', []);
            addParameter(x__inp, 'limit', []);
            addParameter(x__inp, 'skip', []);
            addParameter(x__inp, 'page', []);
            addParameter(x__inp, 'afterId', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.exhaustive)
                queryParams = [queryParams, 'exhaustive', flywheel.ApiClient.castParam(x__inp.Results.exhaustive, 'logical')];
            end
            if ~isempty(x__inp.Results.filter)
                queryParams = [queryParams, 'filter', flywheel.ApiClient.castParam(x__inp.Results.filter, 'char')];
            end
            if ~isempty(x__inp.Results.sort)
                queryParams = [queryParams, 'sort', flywheel.ApiClient.castParam(x__inp.Results.sort, 'char')];
            end
            if ~isempty(x__inp.Results.limit)
                queryParams = [queryParams, 'limit', flywheel.ApiClient.castParam(x__inp.Results.limit, 'integer')];
            else
                queryParams = [queryParams, 'limit', '1000'];
            end
            if ~isempty(x__inp.Results.skip)
                queryParams = [queryParams, 'skip', flywheel.ApiClient.castParam(x__inp.Results.skip, 'integer')];
            end
            if ~isempty(x__inp.Results.page)
                queryParams = [queryParams, 'page', flywheel.ApiClient.castParam(x__inp.Results.page, 'integer')];
            end
            if ~isempty(x__inp.Results.afterId)
                queryParams = [queryParams, 'after_id', flywheel.ApiClient.castParam(x__inp.Results.afterId, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/acquisitions', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.Acquisition.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisition(obj, acquisitionId, body, varargin)
            % Update a acquisition
            % acquisitionId (char)
            % body (Acquisition)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Acquisition.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('PUT', '/acquisitions/{AcquisitionId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisitionAnalysis(obj, acquisitionId, analysisId, body, varargin)
            % Modify an analysis.
            % acquisitionId (char)
            % analysisId (char)
            % body (AnalysisUpdate)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.AnalysisUpdate.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('PUT', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisitionFile(obj, acquisitionId, fileName, body, varargin)
            % Modify a file's attributes
            % acquisitionId (char)
            % fileName (char)
            % body (FileEntry)
            % returns: [InlineResponse2004, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.FileEntry.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('PUT', '/acquisitions/{AcquisitionId}/files/{FileName}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse2004.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisitionFileClassification(obj, acquisitionId, fileName, body, varargin)
            % Update classification for a particular file.
            % acquisitionId (char)
            % fileName (char)
            % body (ClassificationUpdateInput)
            % returns: [InlineResponse2004, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.ClassificationUpdateInput.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/files/{FileName}/classification', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse2004.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisitionFileInfo(obj, acquisitionId, fileName, body, varargin)
            % Update info for a particular file.
            % acquisitionId (char)
            % fileName (char)
            % body (InfoUpdateInput)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.InfoUpdateInput.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/files/{FileName}/info', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisitionInfo(obj, acquisitionId, body, varargin)
            % Update or replace info for a acquisition.
            % acquisitionId (char)
            % body (InfoUpdateInput)
            % returns: [none, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.InfoUpdateInput.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/info', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = modifyAcquisitionNote(obj, acquisitionId, noteId, body, varargin)
            % Update a note on acquisition.
            % acquisitionId (char)
            % noteId (char)
            % body (Note)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'noteId');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, noteId, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.noteId)
                pathParams = [pathParams, 'NoteId', x__inp.Results.noteId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Note.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('PUT', '/acquisitions/{AcquisitionId}/notes/{NoteId}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = renameAcquisitionTag(obj, acquisitionId, tagValue, body, varargin)
            % Rename a tag.
            % acquisitionId (char)
            % tagValue (char):The tag to interact with
            % body (Tag)
            % returns: [InlineResponse200, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'tagValue');
            addRequired(x__inp, 'body');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, tagValue, body, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.tagValue)
                pathParams = [pathParams, 'TagValue', x__inp.Results.tagValue];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = flywheel.model.Tag.ensureIsInstance(x__inp.Results.body);
            body = flywheel.ApiClient.encodeJson(body.toJson());

            resp = obj.apiClient.callApi('PUT', '/acquisitions/{AcquisitionId}/tags/{TagValue}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.InlineResponse200.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = replaceAcquisitionFile(obj, acquisitionId, fileName, varargin)
            % Replace a file
            % acquisitionId (char)
            % fileName (char)
            % returns: [none, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'fileName');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, fileName, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.fileName)
                pathParams = [pathParams, 'FileName', x__inp.Results.fileName];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/files/{FileName}', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = uploadFileToAcquisition(obj, acquisitionId, file, varargin)
            % Upload a file to acquisition.
            % acquisitionId (char)
            % file (char):The file to upload
            % metadata (char):File metadata
            % returns: [none, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'file');
            addParameter(x__inp, 'metadata', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, file, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};
            if ~isempty(x__inp.Results.file)
                files = [files, flywheel.FileSpec.parametrize(x__inp.Results.file)];
            end
            if ~isempty(x__inp.Results.metadata)
                formParams = [formParams, 'metadata', x__inp.Results.metadata];
            end

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/files', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = uploadOutputToAcquisitionAnalysis(obj, acquisitionId, analysisId, file, varargin)
            % Upload an output file to analysis.
            % acquisitionId (char)
            % analysisId (char)
            % file (char):The file to upload
            % returns: [none, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'acquisitionId');
            addRequired(x__inp, 'analysisId');
            addRequired(x__inp, 'file');
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, acquisitionId, analysisId, file, varargin{:});

            % Path parameters
            pathParams = {};
            if ~isempty(x__inp.Results.acquisitionId)
                pathParams = [pathParams, 'AcquisitionId', x__inp.Results.acquisitionId];
            end
            if ~isempty(x__inp.Results.analysisId)
                pathParams = [pathParams, 'AnalysisId', x__inp.Results.analysisId];
            end

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};
            if ~isempty(x__inp.Results.file)
                files = [files, flywheel.FileSpec.parametrize(x__inp.Results.file)];
            end

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('POST', '/acquisitions/{AcquisitionId}/analyses/{AnalysisId}/files', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                otherwise
                    returnData = [];
            end
        end

    end
end
