% ReportsApi - Site-wide reports
%
% ReportsApi Properties:
%    apiClient - ApiClient instance
%
% ReportsApi Methods
%    collectUsage         - Collect daily usage statistics.
%    getAccessLogReport   - Get a report of access log entries for the given parameters
%    getAccessLogTypes    - Get the list of types of access log entries
%    getDailyUsageReport  - Get a daily usage report for the given month.
%    getLegacyUsageReport - Get a usage report for the site grouped by month or project
%    getProjectReport    
%    getSiteReport       
%    getUsageAvailability - Get year/month combinations where report data is available.
%    getUsageReport       - Get a usage report for the given month.
classdef ReportsApi < handle
    % NOTE: This file is auto generated by the swagger code generator program.
    % Do not edit the file manually.
    properties
        apiClient
        context_
    end
    methods
        function obj = ReportsApi(apiClient, context)
            obj.apiClient = apiClient;
            obj.context_ = context;
        end

        function [returnData, resp] = collectUsage(obj, varargin)
            % Collect daily usage statistics.
            % year (integer):The year portion of the date
            % month (integer):The month portion of the date
            % day (integer):The day portion of the date
            % returns: [none, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'year', []);
            addParameter(x__inp, 'month', []);
            addParameter(x__inp, 'day', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.year)
                queryParams = [queryParams, 'year', flywheel.ApiClient.castParam(x__inp.Results.year, 'integer')];
            end
            if ~isempty(x__inp.Results.month)
                queryParams = [queryParams, 'month', flywheel.ApiClient.castParam(x__inp.Results.month, 'integer')];
            end
            if ~isempty(x__inp.Results.day)
                queryParams = [queryParams, 'day', flywheel.ApiClient.castParam(x__inp.Results.day, 'integer')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/usage/collect', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAccessLogReport(obj, varargin)
            % Get a report of access log entries for the given parameters
            % startDate (char):An ISO formatted timestamp for the start time of the report
            % endDate (char):An ISO formatted timestamp for the end time of the report
            % uid (char):User id of the target user
            % limit (integer):Maximum number of records to return
            % subject (char):Limit the report to the subject code of subject accessed
            % project (char):Limit the report to the project id
            % accessType (vector[char]):The list of access_types to filter logs
            % csv (logical):Set to download a csv file instead of json
            % returns: [vector[ReportAccessLogEntry], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'startDate', []);
            addParameter(x__inp, 'endDate', []);
            addParameter(x__inp, 'uid', []);
            addParameter(x__inp, 'limit', []);
            addParameter(x__inp, 'subject', []);
            addParameter(x__inp, 'project', []);
            addParameter(x__inp, 'accessType', []);
            addParameter(x__inp, 'csv', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.startDate)
                queryParams = [queryParams, 'start_date', flywheel.ApiClient.castParam(x__inp.Results.startDate, 'char')];
            end
            if ~isempty(x__inp.Results.endDate)
                queryParams = [queryParams, 'end_date', flywheel.ApiClient.castParam(x__inp.Results.endDate, 'char')];
            end
            if ~isempty(x__inp.Results.uid)
                queryParams = [queryParams, 'uid', flywheel.ApiClient.castParam(x__inp.Results.uid, 'char')];
            end
            if ~isempty(x__inp.Results.limit)
                queryParams = [queryParams, 'limit', flywheel.ApiClient.castParam(x__inp.Results.limit, 'integer')];
            end
            if ~isempty(x__inp.Results.subject)
                queryParams = [queryParams, 'subject', flywheel.ApiClient.castParam(x__inp.Results.subject, 'char')];
            end
            if ~isempty(x__inp.Results.project)
                queryParams = [queryParams, 'project', flywheel.ApiClient.castParam(x__inp.Results.project, 'char')];
            end
            if ~isempty(x__inp.Results.accessType)
                queryParams = flywheel.ApiClient.formatParamCollection(queryParams, 'access_type', x__inp.Results.accessType, 'multi');
            end
            if ~isempty(x__inp.Results.csv)
                queryParams = [queryParams, 'csv', flywheel.ApiClient.castParam(x__inp.Results.csv, 'logical')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/accesslog', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.ReportAccessLogEntry.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getAccessLogTypes(obj, varargin)
            % Get the list of types of access log entries
            % returns: [vector[char], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/accesslog/types', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.char.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getDailyUsageReport(obj, varargin)
            % Get a daily usage report for the given month.
            % year (integer):The year portion of the date
            % month (integer):The month portion of the date
            % group (char):Limit the report to the given group id
            % project (char):Limit the report to the given project id
            % csv (logical):Download the report as a CSV file
            % returns: [vector[ReportDailyUsageEntry], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'year', []);
            addParameter(x__inp, 'month', []);
            addParameter(x__inp, 'group', []);
            addParameter(x__inp, 'project', []);
            addParameter(x__inp, 'csv', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.year)
                queryParams = [queryParams, 'year', flywheel.ApiClient.castParam(x__inp.Results.year, 'integer')];
            end
            if ~isempty(x__inp.Results.month)
                queryParams = [queryParams, 'month', flywheel.ApiClient.castParam(x__inp.Results.month, 'integer')];
            end
            if ~isempty(x__inp.Results.group)
                queryParams = [queryParams, 'group', flywheel.ApiClient.castParam(x__inp.Results.group, 'char')];
            end
            if ~isempty(x__inp.Results.project)
                queryParams = [queryParams, 'project', flywheel.ApiClient.castParam(x__inp.Results.project, 'char')];
            end
            if ~isempty(x__inp.Results.csv)
                queryParams = [queryParams, 'csv', flywheel.ApiClient.castParam(x__inp.Results.csv, 'logical')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/daily-usage', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.ReportDailyUsageEntry.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getLegacyUsageReport(obj, type, varargin)
            % Get a usage report for the site grouped by month or project
            % type (char):The type of usage report to generate
            % startDate (char):An ISO formatted timestamp for the start time of the report
            % endDate (char):An ISO formatted timestamp for the end time of the report
            % returns: [vector[ReportLegacyUsageEntry], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addRequired(x__inp, 'type');
            addParameter(x__inp, 'startDate', []);
            addParameter(x__inp, 'endDate', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, type, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.type)
                queryParams = [queryParams, 'type', flywheel.ApiClient.castParam(x__inp.Results.type, 'char')];
            end
            if ~isempty(x__inp.Results.startDate)
                queryParams = [queryParams, 'start_date', flywheel.ApiClient.castParam(x__inp.Results.startDate, 'char')];
            end
            if ~isempty(x__inp.Results.endDate)
                queryParams = [queryParams, 'end_date', flywheel.ApiClient.castParam(x__inp.Results.endDate, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/legacy-usage', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.ReportLegacyUsageEntry.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getProjectReport(obj, varargin)
            % getProjectReport
            % projects (char):Specify multiple times to include projects in the report
            % startDate (char):Report start date
            % endDate (char):Report end date
            % returns: [ReportProject, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'projects', []);
            addParameter(x__inp, 'startDate', []);
            addParameter(x__inp, 'endDate', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.projects)
                queryParams = [queryParams, 'projects', flywheel.ApiClient.castParam(x__inp.Results.projects, 'char')];
            end
            if ~isempty(x__inp.Results.startDate)
                queryParams = [queryParams, 'start_date', flywheel.ApiClient.castParam(x__inp.Results.startDate, 'char')];
            end
            if ~isempty(x__inp.Results.endDate)
                queryParams = [queryParams, 'end_date', flywheel.ApiClient.castParam(x__inp.Results.endDate, 'char')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/project', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.ReportProject.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getSiteReport(obj, varargin)
            % getSiteReport
            % returns: [ReportSite, resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/site', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.model.ReportSite.fromJson(json, obj.context_);
                    if ~isempty(returnData)
                        returnData = returnData.returnValue();
                    end
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getUsageAvailability(obj, varargin)
            % Get year/month combinations where report data is available.
            % returns: [vector[ReportTimePeriod], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/usage/availability', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.ReportTimePeriod.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

        function [returnData, resp] = getUsageReport(obj, varargin)
            % Get a usage report for the given month.
            % year (integer):The year portion of the date
            % month (integer):The month portion of the date
            % csv (logical):Download the report as a CSV file
            % returns: [vector[ReportUsageEntry], resp]

            x__inp = inputParser;
            x__inp.StructExpand = false;
            addParameter(x__inp, 'year', []);
            addParameter(x__inp, 'month', []);
            addParameter(x__inp, 'csv', []);
            addParameter(x__inp, 'DumpResponseData', false);
            parse(x__inp, varargin{:});

            % Path parameters
            pathParams = {};

            % Query parameters
            queryParams = {};
            if ~isempty(x__inp.Results.year)
                queryParams = [queryParams, 'year', flywheel.ApiClient.castParam(x__inp.Results.year, 'integer')];
            end
            if ~isempty(x__inp.Results.month)
                queryParams = [queryParams, 'month', flywheel.ApiClient.castParam(x__inp.Results.month, 'integer')];
            end
            if ~isempty(x__inp.Results.csv)
                queryParams = [queryParams, 'csv', flywheel.ApiClient.castParam(x__inp.Results.csv, 'logical')];
            end

            % Header parameters
            headers = {};

            % Form parameters
            formParams = {};
            files = {};

            % Body (as JSON)
            body = {};

            resp = obj.apiClient.callApi('GET', '/report/usage', ...
                pathParams, queryParams, headers, body, formParams, files);

            status = resp.getStatusCode();

            switch num2str(status)
                case '200'
                    if x__inp.Results.DumpResponseData
                        x__respData = resp.getBodyAsString();
                        disp(x__respData);
                    end
                    json = flywheel.ApiClient.getResponseJson(resp);
                    returnData = flywheel.ModelBase.cellmap(@(x) flywheel.model.ReportUsageEntry.fromJson(x, obj.context_), json);
                otherwise
                    returnData = [];
            end
        end

    end
end
